#!/bin/bash
# Copyright (C) 2012 - 2020 FARGOS Development, LLC
# $Id: pathCondense.sh b47bdfaa03579cde2993b2cc6da898e5d301a290 Fri Oct 4 01:38:52 2019 -0400 <gcc@fargos.net> $
# eliminate redundant path elements
# NOTE:  this shell script implementation has an alternate native implementation
# in pathCondense.cpp

# PORTABILITY NOTE: this uses arrays to preserve the structure of each
# command line token.
# Since bash was chosen as the implementation target, native arithmetic
# expressions are used.

declare -a argList # this will be an array
argCount=0

initialPath=""
pathSeparator=':'
inputSeparator=':'
mustExist=0

while test $# -gt 0
do
	case "${1}" in
	-h | -help | --help)
		printf "usage: %s [{{-s separator} | --space}] [-x] dir [...]\n" "${0}" >&2
		printf "  -s = specifies output separator for path elements, defaults to \"%s\"\n" "${pathSeparator}" >&2
		printf "  --is = specify input separator, defaults to \"%s\"\n" "${inputSeparator}" >&2
		printf "  --space = use space as output separator\n" >&2
		printf "  -x = only include filesystem elements that exist\n" >&2
		exit 1
		;;
	-s | -os | --os)
		pathSeparator="${2}"
		shift
		;;
	-is | --is)
		inputSeparator="${2}"
		shift
		;;
	-space | --space)
		pathSeparator=' '
		;;
	-x)
		mustExist=1
		;;
	*)
		argText="${1}"
		while test ${#argText} -ne 0
		do
			arg="${argText%%${inputSeparator}*}"
			argCount=$(( argCount + 1 ))
			argList[${argCount}]="${arg}"
			argText="${argText:$(( ${#arg} + 1 ))}"
		done
		argCount=$(( argCount + 1 ))
		argList[${argCount}]="${argText}"
		;;
	esac
	shift
done

didElems=""
newPath=""
for elem in "${argList[@]}"
do
	if test ${mustExist} -eq 1
	then
		if test ! -e "${elem}"
		then # doesn't exist, skip to next element
			continue
		fi
	fi
	did=`expr "_${didElems}_" : '.*'"@${elem}@"`
	if test "${did}" -eq 0
	then
		newPath="${newPath}${newPath:+${pathSeparator}}${elem}"
		didElems="${didElems}@${elem}@"
	fi
done
echo ${newPath}
exit 0
