# Copyright (C) 2014 - 2018 FARGOS Development, LLC
# $Id:  $
# used by replacePathVars to do substitute and replace
# VARS_OF_INTEREST specifies comma-separated list of environment variables
# that specifies variable names associated with a path.  Variables are
# normally prefixed with "_REALPATH_".

BEGIN {
	n = split(VARS_OF_INTEREST, varList, ",");
	varCount = 0;
	for(i=1;i<= n;i+=1) {
		if (! (varList[i] in ENVIRON)) {
#			printf("No such environment variable %s\n", varList[i]) > "/dev/stderr";
			continue;
		}
		varCount += 1;
		key = varList[i];
		if (length(key) > 10) { # perhaps a real path specification
			if (substr(key, 1, 10) == "_REALPATH_") {
				# get key from _REALPATH_XXX
				key = substr(key, 11);
			}
		}
		varName[varCount] = key; # save name to use...
		pathName[varCount] = ENVIRON[varList[i]];
		pathLen[varCount] = length(pathName[varCount]);
		# the subscript is embedded in the key so we can
		# extract it later, but it also retains the order
		# (priority) of the original elements.
		# Note, though, that the search order will be from
		# last to first (to find longest prefix first).
		key = sprintf("%3.3d:%3.3d", 
			length(pathName[varCount]), varCount);
		pathLenKey[varCount] = key;
	}
	for(i=1;i<=varCount;i+=1) {
		pathOrder[pathLenKey[i]] = i;
	}
	asorti(pathOrder, sortedPathOrder);
	for(i=1;i<=varCount;i+=1) {
		key = pathOrder[sortedPathOrder[i]];
		j = 1 * substr(key, index(key, ":") + 1);
		searchOrder[i] = (varCount - i) + 1; # just keep it as-is, was j
	}
}

{
	l = length($0);
	# get exact copy of white space representing leading part of line 
	sepChar = "";
	for(i=1;i<l;i+=1) {
		blank = substr($0, i, 1);
		if ((blank != " ") && (blank != "\t")) {
			break;
		}
		sepChar = sepChar blank;
	}
	for(i=1;i<=NF;i+=1) {
		printf("%s", sepChar);
		sepChar = FS;
		if (substr($i, 1, 1) != "/") { # not absolute path
			printf("%s", $i);
			continue;
		}
		l = length($i);
		text = "";
		for(j=varCount;j>0;j-=1) {
			k = searchOrder[j];
			if (l < pathLen[k]) { # too short for a match
				continue;
			}
			prefix = substr($i, 1, pathLen[k]);
			if (prefix == pathName[k]) {
				text = sprintf("${%s}%s", varName[k],
					substr($i, pathLen[k] + 1));
				break;
			}
		}
		if (text != "") {
			printf("%s", text);
		} else {
			printf("%s", $i);
		}
	}
	printf("\n");
}
