#!/bin/sh
# Compile path-related commands for performance
# $Id: compileSandboxPathCommands.sh 838faeb8271df8493f48a346642a21aee01692b7 Sun Jul 26 18:13:17 2020 -0400 <gcc@fargos.net> $
CXX_COMP=${CXX:-g++}
STD=-std=c++17

toolRoot="${SB_TOOLS_ROOT}"
if test -z "${toolRoot}"
then
	printf "%s: SB_TOOLS_ROOT environment variable not set\n" "${0}" >&2
	exit 1
fi
originDir=`dirname ${0}`

if test -z "${SB_TARGET_ARCH}"
then
	_osName=`uname -s`
	case "${_osName}" in
	CYGWIN* | Win*) 
		_osName="Windows"
		EXE_SUFFIX=".exe"
		EXTRA_LDFLAGS="-static"
		;;
	esac
	osDir=${_osName}.`uname -m`
else
	osDir=${SB_TARGET_ARCH}
fi

mkdir -p ${toolRoot}/${osDir}/bin
progList=""
for prog in findFile pathCondense encapsulateArguments
do
	echo ${CXX_COMP} ${EXTRA_LDFLAGS} -O3 ${STD} -o ${toolRoot}/${osDir}/bin/${prog}${EXE_SUFFIX} ${originDir}/${prog}.cpp
	${CXX_COMP} ${EXTRA_LDFLAGS} -O3 ${STD} -o ${toolRoot}/${osDir}/bin/${prog}${EXE_SUFFIX} ${originDir}/${prog}.cpp
	rc=$?
	if test ${rc} -ne 0
	then
		printf "%s: failed to compile %s.cpp\n" "${0}" ${prog} >&2
		exit 1
	fi
	if test -z "${progList}"
	then
		progList="${prog}"
		sep=" and"
	else
		progList="${prog}${sep} ${progList}"
		sep=","
	fi
done
echo Installed ${progList:-NOTHING} to ${toolRoot}/${osDir}/bin
exit 0
