/* Add quotes to command line arguments, if needed.
 * Copyright (C) 2014 - 2018 FARGOS Development, LLC
 */
#include <stdio.h>
#include <ctype.h>
#include <stdlib.h>
#include <fcntl.h>
#include <iostream>

const char srcID[] = "$Id: encapsulateArguments.cpp 51ae124675508e2c0533b2fc633705a3c6c8b161 Sat Jun 1 14:47:25 2019 -0400 <gcc@fargos.net> $";

int main(int argc, const char *argv[])
{
#ifdef _WIN32
    _setmode(_fileno(stdout), _O_BINARY);
#endif
	const char *quoteChar = getenv("ENCAPSULATE_QUOTE_CHAR");
	if (quoteChar == nullptr) {
		quoteChar = "'";
	}

	for(int i=1;i<argc;i+=1) {
		bool sawSpace = false;
		bool sawSpecialCharacter = false;
		bool sawDoubleQuote = false;
		bool sawSingleQuote = false;
		bool sawQuotingChar = false;

		const char *cp = argv[i];
		if (*cp == '\0') { // null string
			sawSpace = true;
		}
		while (*cp != '\0') {
			if (*cp == *quoteChar) {
				sawQuotingChar = true;
			}
			switch (*cp) {
			case '\t':
			case ' ':
				sawSpace = true;
				break;
			case '*':
			case '?':
			case '(':
			case ')':
			case '[':
			case ']':
				sawSpecialCharacter = true;
				break;
			case '"':
				sawDoubleQuote = true;
				break;
			case '\'':
				sawSingleQuote = true;
				break;
			} // end switch
			cp += 1;
		}
		if (i != 1) {
			std::cout << " ";
		}
		if (sawQuotingChar) { // escape it
			cp = argv[i];
			std::cout << quoteChar;
			while (*cp != '\0') {
				if (*cp == *quoteChar) {
					std::cout << '\\';
				}
				std::cout << *cp;
			}
			std::cout << quoteChar;
		} else if (sawSpace || sawSpecialCharacter) {
			std::cout << quoteChar << argv[i] << quoteChar;
		} else {
			std::cout << argv[i];
		}
	}
	std::cout << "\n";
	std::cout.flush();
	return (0);
}
