# Path setup for sandbox tools for Bourne/bash shell
# This file is normally installed as /etc/profile.d/sandbox_tools.sh
# NOTE: ensure the settings of BT_ROOT_PATH and SB_TOOLS_ROOT are appropriate
# for the local system.
# The remaining can be altered as an administrator sees fit,
# but the calculated values are normally ideal.
# $Id: sandbox_tools.sh 3fca964920a13dd355b7cd179105ede85b9222c6 Tue Jun 30 23:13:00 2020 -0400 <gcc@fargos.net> $

# Obtain native architecture
_local_OS=`uname -s`
case "${_local_OS}" in
CYGWIN* | Win*)
	_local_OS="Windows"
	;;
esac
_local_CPU=`uname -m`

# Obtain native architecture
SB_NATIVE_ARCH="${_local_OS}.${_local_CPU}"
export SB_NATIVE_ARCH

# Local preference for location of backing trees
# ------ EDIT THIS SETTING APPROPRIATELY! ------
BT_ROOT_PATH="${BT_ROOT_PATH:-/storage/backingTrees:/opt/backingTrees}"
export BT_ROOT_PATH


# Point to installation root of sandbox tools suite
# ------ EDIT THIS SETTING APPROPRIATELY! ------
SB_TOOLS_ROOT="${SB_TOOLS_ROOT:-/opt/sandboxTools}"
export SB_TOOLS_ROOT

_default_SB_NOARCH_BIN_PATH=${SB_TOOLS_ROOT}/${_local_OS}.noarch/bin
SB_TOOLS_BIN_DIR=${SB_TOOLS_BIN_DIR:-${_default_SB_NOARCH_BIN_PATH}}
export SB_TOOLS_BIN_DIR

_default_SB_NATIVE_BIN_PATH=${SB_TOOLS_ROOT}/${SB_NATIVE_ARCH}/bin
_default_SB_BIN_PATH=${_default_SB_NATIVE_BIN_PATH}:${_default_SB_NOARCH_BIN_PATH}

SB_TOOLS_BIN_PATH="${SB_TOOLS_BIN_PATH:-${_default_SB_BIN_PATH}}"
export SB_TOOLS_BIN_PATH

# Add to regular PATH
# pathCondense might not be available the first time this is installed
# but eventually should be....
if test -x "${_default_SB_NATIVE_BIN_PATH}/pathCondense"
then
	PATH=`${_default_SB_NATIVE_BIN_PATH}/pathCondense "${PATH}" "${SB_TOOLS_BIN_PATH}"`
else
	PATH="${PATH}${PATH:+:}${SB_TOOLS_BIN_PATH}"
fi
export PATH

# Define primary backing tree root by taking first directory in path
BT_ROOT_DIR=`pathedit --space "${BT_ROOT_PATH}" | awk '{ print $1; }'`
export BT_ROOT_DIR
